

FEMAG Tools 
===========
.. image:: https://travis-ci.org/SEMAFORInformatik/femagtools.svg?branch=master
    :target: https://travis-ci.org/SEMAFORInformatik/femagtools

Femagtools is an Open-Source Python-API for FEMAG offering following features:

* run Femag with a FSL file anywhere:
  locally (single and multi-core), remote (ZMQ), HT Condor, Cloud (Amazon AWS, Google Cloud)
* read ISA/BCH/BATCH/PLT files
* read and write MCV files (magnetizing curves)
* create a variety of plots
* create FSL files from model and calculation templates and/or user specific FSL or from DXF
* create FSL files from DXF
* calculate machine characteristics by using analytic machine models
* execute parameter studies and multi-objective optimization

Further Information: http://docs.semafor.ch/femagtools
